@@ -115,4 +115,13 @@ W_1 <- function(z) {
 W_gamma_1 <- function(z, gamma) {
   warning("DEPRECATED: Please use W_gamma(..., branch = -1) instead of W_gamma_1(...).")
   W_gamma(z, gamma, branch = -1)
-} 
\ No newline at end of file
+} 
+
+
+#' @rdname deprecated-functions
+#' @export
+H <- function(...) {
+  warning("DEPRECATED: Please use xexp(...) instead of H(...).")
+  
+  return(xexp(...))
+}
